#!/usr/bin/perl
use strict;
use warnings;
use FileHandle;
use File::Find;

###################################################
##               Script2-REDDB.pl                ##
##                 Version 1.01                  ##
##                                               ##
##      Automatic submission in R.E.DD.B.        ##
##    http://q4md-forcefieldtools.org/REDDB/     ##
##                                               ##
##                UPJV - SBMRI                   ##
##                                               ##
##   See the license of the R.E.D.-III.x tools   ##
###################################################
##
## Version 1.0  - November 24th, 2011
## Version 1.01 - December 8th, 2011
## - Correction of a bug in the date (lines 630-631)
##
## *****************************************************************
##    Program developed at the UFR de Pharmacie in Amiens by:
##     Q. Defarcy,(1) P. Cieplak (2) & F.-Y. Dupradeau (1)
##
## (1) UMR-CNRS 6219, UFR de Pharmacie, Amiens, France
## (2) Sanford|Burnham Medical Research Institute, La Jolla, CA, USA
## *****************************************************************
##
##              Execution:
## perl script2-REDDB.pl DataDirectory-config.cfg
##   "DataDirectory-config.cfg": file generated by the program Script1-REDDB.pl
##  -> a DataDirectory-insert.sql file and a W-X/F-X directory are generated
##
## Create an compressed archine file for these data and send it to 
##        contact@q4md-forcefieldtools.org
##
## Do you have questions about this program?
## Please register @ http://lists.q4md-forcefieldtools.org/wws/info/q4md-fft
##  & send your queries to the q4md-fft mailing list

my $NBLine1;
my $NBLine2;
my $NBLine3;
my $SQLFile;
my @WP;
my @FP;
my $NbP;
my $WP;
my $FP;
my @TriposF;
my @PDBF;
my @RespIF;
my $TriposF;
my $PDBF;
my $RespIF;
my $NbF;
my $NbUserTemp1;
my $NbUserTemp2;
my $NbpwdTemp1;
my $NbpwdTemp2;
my @NbUser2;
my @Nbpwd2;
my $Nbpwd;
my @NbUser1;
my @NbUser;
my $NbUser;
my $useremail;
my $N1;
my $N2;

my $Project_Name;
my $Protect;
my $ProtectPeriod;
my $REDDB_Root_Login;
my $REDDB_Root_Password;
my $REDDB_Login;
my $REDDB_Password;
my $Molecule_Keyword_tmp;
my @Molecule_Keyword;
my $Abstract;
my $Published;
my $Pubinfo_tmp;
my @Pubinfo;
my $WholeFragment;
my $WholeFragmentDir;
my $REDInterface;
my @TriposFile_Name;
my @TriposFile_Name_tmp;
my @molinfo;
my @molinfo_tmp;
my $Geo_Program;
my $Geo_ProgramDB;
my $Geo_TL;
my $Geo_TL1;
my $Geo_MoreInfo;
my $Geo_BasisSet;
my $Geo_BasisSetDB;
my $Elec_Program;
my $Elec_ProgramDB;
my $Elec_TL;
my $Elec_TL1;
my $Elec_MoreInfo;
my $Elec_BasisSet;
my $Elec_BasisSetDB;
my $Elec_SurfAlgo;
my @Input_file_tmp;
my @Input_file;
my @FF_File_tmp;
my @FF_File;
my $nbp2n;
my $Pathfile;
my $initialnamefile_pdb;
my $initialnamefile_mol2;
my $initialnamefile_inp;
my $initialnamefile_ff;
my $namefile_pdb;
my $namefile_mol2;
my $namefile_inp;
my $namefile_ff;
my $softwaremolinfo;
my $dirserver;

my $i_pdb = 0;
my $i_mol2 = 0;
my $i_file = 0;
my $i_inp = 0;
my $verif;
my $Error;
my $ErrorRoot;
my $ErrorPassword;
my $ResultVerifDir;
my $ResultTestCont;
my $ResultIfRoot;
my $ResultVerifPassword;
my $DirPar;
my $dateUs;
my $DateProtect;

$dirserver = 'review';

sub VerifDir{
	$verif = 0;
	if (($#ARGV == 0)){
		if (-f "$ARGV[0]"){
		}else{
			$verif = 1;
			print "\n===================================================================\n";
			print "File $ARGV[0] is not found!\t\t[ERROR]\n";
			print "===================================================================\n\n";
		}
	}else{
		$verif = 1;
		print "\n===================================================================\n";
		print "Provide a pathfile name...\t\t\t\t[ERROR]\n";
		print "===================================================================\n\n";
	}
	return $verif;
}

sub RecupData{
	open(CONFIG,"$ARGV[0]");
	while(<CONFIG>){
		if((/<REDDB_Root_Login>/ .. /<!_REDDB_Root_Login>/)){
			if (($_ !~ /<REDDB_Root_Login>/) && ($_ !~ /<!_REDDB_Root_Login>/)){
				$REDDB_Root_Login =  $_;
				$REDDB_Root_Login =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<REDDB_Root_Password>/ .. /<!_REDDB_Root_Password>/)){
			if (($_ !~ /<REDDB_Root_Password>/) && ($_ !~ /<!_REDDB_Root_Password>/)){
				$REDDB_Root_Password =  $_;
				$REDDB_Root_Password =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<Your_REDDB_Login>/ .. /<!_Your_REDDB_Login>/)){
			if (($_ !~ /<Your_REDDB_Login>/) && ($_ !~ /<!_Your_REDDB_Login>/)){
				$REDDB_Login =  $_;
				$REDDB_Login =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<Your_REDDB_Password>/ .. /<!_Your_REDDB_Password>/)){
			if (($_ !~ /<Your_REDDB_Password>/) && ($_ !~ /<!_Your_REDDB_Password>/)){
				$REDDB_Password =  $_;
				$REDDB_Password =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<Project_Name>/ .. /<!_Project_Name>/)){
			if (($_ !~ /<Project_Name>/) && ($_ !~ /<!_Project_Name>/)){
				$Project_Name = $_;
				$Project_Name =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<Protect>/ .. /<!_Protect>/)){
			if (($_ !~ /<Protect>/) && ($_ !~ /<!_Protect>/)){
				$Protect =  uc($_);
				$Protect =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<ProtectPeriod>/ .. /<!_ProtectPeriod>/)){
			if (($_ !~ /<ProtectPeriod>/) && ($_ !~ /<!_ProtectPeriod>/)){
				$ProtectPeriod = $_;
				$ProtectPeriod =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<Molecule_Keyword>/ .. /<!_Molecule_Keyword>/)){
			if (($_ !~ /<Molecule_Keyword>/) && ($_ !~ /<!_Molecule_Keyword>/)){
				$Molecule_Keyword_tmp =  $_;
				$Molecule_Keyword[0]= (split('<!>',$Molecule_Keyword_tmp))[0];
				$Molecule_Keyword[0]=~ s/^\s*(.*?)\s*$/$1/;
				$Molecule_Keyword[1]= (split('<!>',$Molecule_Keyword_tmp))[1];
				$Molecule_Keyword[1]=~ s/^\s*(.*?)\s*$/$1/;
				$Molecule_Keyword[2]= (split('<!>',$Molecule_Keyword_tmp))[2];
				$Molecule_Keyword[2]=~ s/^\s*(.*?)\s*$/$1/;
				$Molecule_Keyword[3]= (split('<!>',$Molecule_Keyword_tmp))[3];
				$Molecule_Keyword[3]=~ s/^\s*(.*?)\s*$/$1/;
				$Molecule_Keyword[4]= (split('<!>',$Molecule_Keyword_tmp))[4];
				$Molecule_Keyword[4]=~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<Abstract>/ .. /<!_Abstract>/)){
			if (($_ !~ /<Abstract>/) && ($_ !~ /<!_Abstract>/)){
				$Abstract =  $_;
			}
		}
		if((/<Published>/ .. /<!_Published>/)){
			if (($_ !~ /<Published>/) && ($_ !~ /<!_Published>/)){
				$Published =  uc($_);
				$Published =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<Pubinfo>/ .. /<!_Pubinfo>/)){
			if (($_ !~ /<Pubinfo>/) && ($_ !~ /<!_Pubinfo>/)){
				$Pubinfo_tmp =  $_;
				$Pubinfo[0]= (split('<!>',$Pubinfo_tmp))[0];
				$Pubinfo[0]=~ s/^\s*(.*?)\s*$/$1/;
				$Pubinfo[1]= (split('<!>',$Pubinfo_tmp))[1];
				$Pubinfo[1]=~ s/^\s*(.*?)\s*$/$1/;
				$Pubinfo[2]= (split('<!>',$Pubinfo_tmp))[2];
				$Pubinfo[2]=~ s/^\s*(.*?)\s*$/$1/;
				$Pubinfo[3]= (split('<!>',$Pubinfo_tmp))[3];
				$Pubinfo[3]=~ s/^\s*(.*?)\s*$/$1/;
				$Pubinfo[4]= (split('<!>',$Pubinfo_tmp))[4];
				$Pubinfo[4]=~ s/^\s*(.*?)\s*$/$1/;
				$Pubinfo[5]= (split('<!>',$Pubinfo_tmp))[5];
				$Pubinfo[5]=~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<WholeFragment>/ .. /<!_WholeFragment>/)){
			if (($_ !~ /<WholeFragment>/) && ($_ !~ /<!_WholeFragment>/)){
				$WholeFragment =  uc($_);
				$WholeFragment =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<REDInterface>/ .. /<!_REDInterface>/)){
			if (($_ !~ /<REDInterface>/) && ($_ !~ /<!_REDInterface>/)){
				$REDInterface =  uc($_);
				$REDInterface =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<nbp2n>/ .. /<!_nbp2n>/)){
			if (($_ !~ /<nbp2n>/) && ($_ !~ /<!_nbp2n>/)){
				$nbp2n =  $_;
				$nbp2n =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<TriposFile_Name>/ .. /<!_TriposFile_Name>/)){
			if (($_ !~ /<TriposFile_Name>/) && ($_ !~ /<!_TriposFile_Name>/)){
				$TriposFile_Name_tmp[$i_mol2] = $_ ;
				# (NMF) Name for the corresponding molecule/fragment
				$TriposFile_Name[$i_mol2][0]= (split('<!>',$TriposFile_Name_tmp[$i_mol2]))[1];
				$TriposFile_Name[$i_mol2][0]=~ s/^\s*(.*?)\s*$/$1/;
				# (PF)  Path to the Tripos mol2 file and file name
				$TriposFile_Name[$i_mol2][1]= (split('<!>',$TriposFile_Name_tmp[$i_mol2]))[2];
				$TriposFile_Name[$i_mol2][1]=~ s/^\s*(.*?)\s*$/$1/;
				$i_mol2++;
			}
		}
		if((/<PDBFile_Name>/ .. /<!_PDBFile_Name>/)){
			if (($_ !~ /<PDBFile_Name>/) && ($_ !~ /<!_PDBFile_Name>/)){
				$molinfo_tmp[$i_pdb] =  $_;
				# (MN) Molecule name (following IUPAC rules)
				$molinfo[$i_pdb][0]= (split('<!>',$molinfo_tmp[$i_pdb]))[1];
				$molinfo[$i_pdb][0] =~ s/^\s*(.*?)\s*$/$1/;
				# (NC) Number of molecular conformation(s) for the considered molecule
				$molinfo[$i_pdb][1]= (split('<!>',$molinfo_tmp[$i_pdb]))[2];
				$molinfo[$i_pdb][1] =~ s/^\s*(.*?)\s*$/$1/;
				# (RP) Reorientation procedure used before MEP computation: QMRA or RBRA
				$molinfo[$i_pdb][2]= (split('<!>',$molinfo_tmp[$i_pdb]))[3];
				$molinfo[$i_pdb][2] =~ s/^\s*(.*?)\s*$/$1/;
				# (NO) Number of molecular orientation(s) for each conformation
				$molinfo[$i_pdb][3]= (split('<!>',$molinfo_tmp[$i_pdb]))[4];
				$molinfo[$i_pdb][3] =~ s/^\s*(.*?)\s*$/$1/;
				# (PF) Path to the PDB file and file name
				$molinfo[$i_pdb][4]= (split('<!>',$molinfo_tmp[$i_pdb]))[5];
				$molinfo[$i_pdb][4] =~ s/^\s*(.*?)\s*$/$1/;
				$i_pdb++;
			}
		}
		if((/<Geo_Program>/ .. /<!_Geo_Program>/)){
			if (($_ !~ /<Geo_Program>/) && ($_ !~ /<!_Geo_Program>/)){
				$Geo_Program =  uc($_);
				$Geo_Program =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<Geo_TL>/ .. /<!_Geo_TL>/)){
			if (($_ !~ /<Geo_TL>/) && ($_ !~ /<!_Geo_TL>/)){
				$Geo_TL =  uc($_);
				$Geo_TL =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<Geo_MoreInfo>/ .. /<!_Geo_MoreInfo>/)){
			if (($_ !~ /<Geo_MoreInfo>/) && ($_ !~ /<!_Geo_MoreInfo>/)){
				$Geo_MoreInfo =  $_;
				$Geo_MoreInfo =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<Geo_BasisSet>/ .. /<!_Geo_BasisSet>/)){
			if (($_ !~ /<Geo_BasisSet>/) && ($_ !~ /<!_Geo_BasisSet>/)){
				$Geo_BasisSet =  uc($_);
				$Geo_BasisSet =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<Elec_Program>/ .. /<!_Elec_Program>/)){
			if (($_ !~ /<Elec_Program>/) && ($_ !~ /<!_Elec_Program>/)){
				$Elec_Program =  uc($_);
				$Elec_Program =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<Elec_TL>/ .. /<!_Elec_TL>/)){
			if (($_ !~ /<Elec_TL>/) && ($_ !~ /<!_Elec_TL>/)){
				$Elec_TL =  uc($_);
				$Elec_TL =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<Elec_MoreInfo>/ .. /<!_Elec_MoreInfo>/)){
			if (($_ !~ /<Elec_MoreInfo>/) && ($_ !~ /<!_Elec_MoreInfo>/)){
				$Elec_MoreInfo =  $_;
				$Elec_MoreInfo =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<Elec_BasisSet>/ .. /<!_Elec_BasisSet>/)){
			if (($_ !~ /<Elec_BasisSet>/) && ($_ !~ /<!_Elec_BasisSet>/)){
				$Elec_BasisSet =  uc($_);
				$Elec_BasisSet =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<Elec_SurfAlgo>/ .. /<!_Elec_SurfAlgo>/)){
			if (($_ !~ /<Elec_SurfAlgo>/) && ($_ !~ /<!_Elec_SurfAlgo>/)){
				$Elec_SurfAlgo =  uc($_);
				$Elec_SurfAlgo =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
		if((/<Input_file>/ .. /<!_Input_file>/)){
			if (($_ !~ /<Input_file>/) && ($_ !~ /<!_Input_file>/)){
				$Input_file_tmp[$i_inp] =  $_;
				# (MN) Molecule name (following IUPAC rules)
				$Input_file[$i_inp][0]= (split('<!>',$Input_file_tmp[$i_inp]))[1];
				$Input_file[$i_inp][0] =~ s/^\s*(.*?)\s*$/$1/;
				$i_inp++;
			}
		}
		if((/<FF_File>/ .. /<!_FF_File>/)){
			if (($_ !~ /<FF_File>/) && ($_ !~ /<!_FF_File>/)){
				$FF_File_tmp[$i_file] =  $_;
				# (YN) 'Yes' or 'No'
				$FF_File[$i_file][0]= (split('<!>',$FF_File_tmp[$i_file]))[1];
				$FF_File[$i_file][0]= uc($FF_File[$i_file][0]);
				$FF_File[$i_file][0] =~ s/^\s*(.*?)\s*$/$1/;
				# (PF) If Yes, provide the path to the file and the file name.
				$FF_File[$i_file][1]= (split('<!>',$FF_File_tmp[$i_file]))[2];
				$FF_File[$i_file][1] =~ s/^\s*(.*?)\s*$/$1/;
				$i_file++;
			}
		}
		if((/<Pathfile>/ .. /<!_Pathfile>/)){
			if (($_ !~ /<Pathfile>/) && ($_ !~ /<!_Pathfile>/)){
				$Pathfile =  $_;
				$Pathfile =~ s/^\s*(.*?)\s*$/$1/;
			}
		}
	}
	close(CONFIG);
}

sub IfRoot{
	$ErrorRoot = 0;
	if(($REDDB_Root_Login eq "") || ($REDDB_Root_Login =~ /^_/)){
		$ErrorRoot = 1;
		print"- Warning: <REDDB_Root_Login>\n";
	}

	if(($REDDB_Root_Password eq "") || ($REDDB_Root_Password =~ /^_/)){
		$ErrorRoot = 1;
		print"- Warning: <REDDB_Root_Password>\n";
	}
}

sub VerifPassword{ $ErrorPassword = 0; }

#======================= TestCont =========================
sub TestCont{
	$Error = 0;
	# if(($REDDB_Login eq "") || ($REDDB_Login =~ /^_/) || ($REDDB_Login =~/\w{76}/)){
	# 	$Error = 1;
	# 	print"- Error: <REDDB_Login>\n";
	# }
	# if(($REDDB_Password eq "") || ($REDDB_Password =~ /^_/) || ($REDDB_Password =~ /\w{6}/) || ($REDDB_Password !~ /\w{4}/)){
	# 	$Error = 1;
	# 	print"- Error: <REDDB_Password>\n";
	# }
	if(($REDDB_Login eq "") || ($REDDB_Login =~ /^_/) || ($REDDB_Login =~/\w{76}/)){
		print"- Warning: <REDDB_Login>\n";
	}
	if(($REDDB_Password eq "") || ($REDDB_Password =~ /^_/) || ($REDDB_Password =~ /\w{6}/) || ($REDDB_Password !~ /\w{4}/)){
		print"- Warning: <REDDB_Password>\n";
	}	
	if(($Project_Name eq "") || ($Project_Name =~ /^_/)){    # Nbre de caracteres versus MySQL DB
		$Error = 1;
		print"- Error: <Project_Name>\n";
	}
	if((($Protect eq "") || ($Protect =~ /^_/)) || (($Protect ne "YES") && ($Protect ne "NO"))){
		$Error = 1;
		print"- Error: <Protect>\n";
	}else{
		if( $Protect eq "YES"){
			if(($ProtectPeriod eq "") || ($ProtectPeriod =~ /^_/) || (($ProtectPeriod ne "3") && ($ProtectPeriod ne "6") && ($ProtectPeriod ne "12"))){
				$Error = 1;
				print"- Error: <ProtectPeriod>\n";
			}
		}
	}
	my $Test_key_tmp;
	for (my $Test_key=0; $Test_key<=4; $Test_key++){
		if(($Molecule_Keyword[$Test_key] eq "") || ($Molecule_Keyword[$Test_key] =~ /^_/) || ($Molecule_Keyword[$Test_key] =~ /\w{101}/)){
			$Error = 1;
			$Test_key_tmp = $Test_key +1;
			print"- Error: <Molecule_Keyword> $Test_key_tmp\n";
		}
	}
	if(($Abstract eq "") || ($Abstract =~ /^__/)){
		$Error = 1;
		print"- Error: <Abstract>\n";
	}
	if(($Published eq "") || ($Published =~ /^_/) || (($Published ne "YES") && ($Published ne "NO"))){
		$Error = 1;
		print"- Error: <Published>\n";
	}else{
		if ($Published eq "YES"){
			for (my $TestPub = 0; $TestPub<=5; $TestPub++){  # Code to be further developed...
				if(($Pubinfo[$TestPub] eq "") || ($Pubinfo[$TestPub] =~ /^_/) || ($Pubinfo[$TestPub] =~ /\w{251}/)){
					$Error = 1;
					print"- Error: <Pubinfo>\n";
				}
			}
		}
	}
	if(($WholeFragment eq "") || ($WholeFragment =~ /^_/) || (($WholeFragment ne "W") && ($WholeFragment ne "F"))){
		$Error = 1;
		print"- Error: <WholeFragment>\n";
	}
	if(($REDInterface eq "") || ($REDInterface =~ /^_/) || (($REDInterface ne "YES") && ($REDInterface ne "NO"))){
		$Error = 1;
		print"- Error: <REDInterface>\n";
	}
	if(($nbp2n eq "") || ($nbp2n =~ /^_/) || ($nbp2n !~ /\d/)){   # Code to be further developed...
		$Error = 1;
		print"- Error: <nbp2n>\n";
	}
	for (my $Test_TriposFile = 0;$Test_TriposFile<$i_mol2;$Test_TriposFile++){
		if(($TriposFile_Name[$Test_TriposFile][0] eq "") || ($TriposFile_Name[$Test_TriposFile][0] =~ /^_/) || ($TriposFile_Name[$Test_TriposFile][0]  =~ /\w{101}/)){
			$Error = 1;
			print"- Error: <TriposFile_Name> (NMF)\n";
		}
		if(($TriposFile_Name[$Test_TriposFile][1] eq "") || ($TriposFile_Name[$Test_TriposFile][1] =~ /^_/)){
			$Error = 1;
			print"- Error: <TriposFile_Name> (PF)\n";
		}
	}
	for (my $Test_PDBFile_Name = 0;$Test_PDBFile_Name<$i_pdb;$Test_PDBFile_Name++){
		if(($molinfo[$Test_PDBFile_Name][0] eq "") || ($molinfo[$Test_PDBFile_Name][0] =~ /^_/)|| ($molinfo[$Test_PDBFile_Name][0] =~ /\w{101}/)){
			$Error = 1;
			print"- Error: <PDBFile_Name> (MN)\n";
		}
		if(($molinfo[$Test_PDBFile_Name][1] eq "") || ($molinfo[$Test_PDBFile_Name][1] =~ /^_/) || ($molinfo[$Test_PDBFile_Name][1] =~ /\d{6}/)){
			$Error = 1;
			print"- Error: <PDBFile_Name> (NC)\n";
		}
		if(($molinfo[$Test_PDBFile_Name][2] eq "") || ($molinfo[$Test_PDBFile_Name][2] =~ /^_/) || ($molinfo[$Test_PDBFile_Name][2] =~ /\w{36}/)){
			$Error = 1;
			print"- Error: <PDBFile_Name> (RP)\n";
		}
		if(($molinfo[$Test_PDBFile_Name][3] eq "") || ($molinfo[$Test_PDBFile_Name][3] =~ /^_/) || ($molinfo[$Test_PDBFile_Name][3] =~ /\d{6}/)){
			$Error = 1;
			print"- Error: <PDBFile_Name> (NO)\n";
		}
		if(($molinfo[$Test_PDBFile_Name][4] eq "") || ($molinfo[$Test_PDBFile_Name][4] =~ /^_/)){
			$Error = 1;
			print"- Error: <PDBFile_Name> (PF)\n";
		}
	}
	if(($Geo_Program eq "") || ($Geo_Program =~ /^_/) || ($Geo_Program =~ /\w{51}/)){
		$Error = 1;
		print"- Error: <Geo_Program>\n";
	}
	if(($Geo_TL eq "") || ($Geo_TL =~ /^_/) || ($Geo_TL =~ /\w{51}/)){
		$Error = 1;
		print"- Error: <Geo_TL>\n";
	}
	if($Geo_MoreInfo =~ /\w{101}/){
		$Error = 1;
		print"- Error: <Geo_MoreInfo>\n";
	}
	else{
		if($Geo_MoreInfo =~ /^_/){ $Geo_MoreInfo = ""; }
	}
	if(($Geo_BasisSet eq "") || ($Geo_BasisSet =~ /^_/) || ($Geo_BasisSet =~ /\w{51}/)){
		$Error = 1;
		print"- Error: <Geo_BasisSet>\n";
	}
	if(($Elec_Program eq "") || ($Elec_Program =~ /^_/) || ($Elec_Program =~ /\w{51}/)){
		$Error = 1;
		print"- Error: <Elec_Program>\n";
	}
	if(($Elec_TL eq "") || ($Elec_TL =~ /^_/) || ($Elec_TL =~ /\w{51}/)){
		$Error = 1;
		print"- Error: <Elec_TL>\n";
	}
	if($Elec_MoreInfo =~ /\w{101}/){
		$Error = 1;
		print"- Error: <Elec_MoreInfo>\n";
	}
	else{
		if($Elec_MoreInfo =~ /^_/){ $Elec_MoreInfo = ""; }
	}
	if(($Elec_BasisSet eq "") || ($Elec_BasisSet =~ /^_/) || ($Elec_BasisSet =~ /\w{51}/)){
		$Error = 1;
		print"- Error: <Elec_BasisSet>\n";
	}
	if(($Elec_SurfAlgo eq "") || ($Elec_SurfAlgo =~ /^_/) || ($Elec_SurfAlgo =~ /\w{51}/)){
		$Error = 1;
		print"- Error: <Elec_SurfAlgo>\n";
	}
	if ($i_inp != 0){
		for (my $Test_InputFile = 0;$Test_InputFile<$i_inp;$Test_InputFile++){
			if(($Input_file[$Test_InputFile][0] eq "") || ($Input_file[$Test_InputFile][0] =~ /^_/)){
				$Error = 1;
				print"- Error: <Input_file>\n";
			}
		}
	}
	for (my $Test_FFFile = 0;$Test_FFFile<=4;$Test_FFFile++){
		if(($FF_File[$Test_FFFile][0] eq "") || ($FF_File[$Test_FFFile][0] =~ /^_/) || (($FF_File[$Test_FFFile][0] ne "YES") && ($FF_File[$Test_FFFile][0] ne "NO"))){
			$Error = 1;
			print"- Error: <FF_File> YN\n";
		}else{
			if($FF_File[$Test_FFFile][0] eq "YES"){
				if (($FF_File[$Test_FFFile][1] eq "") || ($FF_File[$Test_FFFile][1] =~ /^_/)){
					$Error = 1;
					print"- Error: <FF_File> (PF)\n";
				}
			}
		}
	}
	if(($Pathfile eq "") || ($Pathfile =~ /^_/)){
		$Error = 1;
		print"- Error: <Pathfile>\n";
	}
	#======== Test Path =========================
	if($i_pdb != 0){
		for (my $i_test_path_pdb = 0;$i_test_path_pdb<$i_pdb; $i_test_path_pdb++){
			if(-f "$molinfo[$i_test_path_pdb][4]"){
			}else{
				$Error = 1;
				my $nb_test_path_pdb = $i_test_path_pdb +1;
				print "- Error : The PDB file ($nb_test_path_pdb) is not found. Exit\n";
			}
		}
	}
	if($i_mol2 != 0){
		for (my $i_test_path_mol2 = 0;$i_test_path_mol2<$i_mol2;$i_test_path_mol2++){
			if (-f "$TriposFile_Name[$i_test_path_mol2][1]"){
			}else{
				$Error = 1;
				my $nb_test_path_mol2 = $i_test_path_mol2 + 1;
				print "- Error : The MOL2 file ($nb_test_path_mol2) is not found. Exit\n";
			}
		}
	}
	if($i_file != 0){
		for (my $i_test_path_ffile = 0; $i_test_path_ffile<$i_file; $i_test_path_ffile++){
			if($FF_File[$i_test_path_ffile][0] eq "YES"){
				if(-f "$FF_File[$i_test_path_ffile][1]"){
				}else{
					$Error = 1;
					my $nb_test_path_ffile = $i_test_path_ffile + 1;
					print "- Error : The Force Field file ($nb_test_path_ffile) is not found. Exit\n";
				}
			}
		}
	}
	if($i_inp !=0){
		for(my $i_test_path_inp = 0;$i_test_path_inp<$i_inp;$i_test_path_inp++){
			if(-f "$Input_file[$i_test_path_inp][0]"){
			}else{
				$Error = 1;
				my $nb_test_path_inp = $i_test_path_inp + 1;
				print "- Error : The input file ($nb_test_path_inp) is not found. Exit\n";
			}
		}
	}
	return $Error;
}

sub CalculTime{
	my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
	$mon = $mon+1;
	if($min<10) { $min  = "0$min"; }
	if($hour<10){ $hour = "0$hour"; }
	if($mday<10){ $mday = "0$mday"; }
	if($mon<10) { $mon  = "0$mon"; }
	$dateUs =  $mday."-".($mon)."-".(1900+$year)." ".$hour.":".$min;
	if ($Protect eq "YES"){
		$mon = $mon + $ProtectPeriod;
		if($mon>12){
			$mon = $mon - 12;
			$year = $year + 1;
		}
		# if($mday<10){ $mday = "0$mday"; } # bug date protect 12/12/2011
		# if($mon<10){ $mon = "0$mon"; }
		$DateProtect = $mday."-".($mon)."-".(1900+$year);
	}
	else{ $DateProtect = ""; }
}

sub DataMisc{
	$Geo_ProgramDB=$Geo_Program;
	if ($Geo_Program eq "DALTON"){ $Geo_ProgramDB = "Dalton"; }
	elsif ($Geo_Program eq "DEMON") { $Geo_ProgramDB = "deMon";  }
	elsif ($Geo_Program eq "JAGUAR"){ $Geo_ProgramDB = "Jaguar"; }
	elsif ($Geo_Program eq "MOLPRO"){ $Geo_ProgramDB = "Molpro"; }
	elsif ($Geo_Program eq "NWCHEM"){ $Geo_ProgramDB = "NWChem"; }
	#-------------------------
	if ($Geo_TL eq "HF") { $Geo_TL1 = "HF"; $Geo_TL = ""; }
	elsif ($Geo_TL eq "RHF") { $Geo_TL1 = "RHF"; $Geo_TL = ""; }
	elsif ($Geo_TL eq "UHF"){ $Geo_TL1 = "UHF"; $Geo_TL = ""; }
	elsif (($Geo_TL eq "PM3") || ($Geo_TL eq "AM1")){ $Geo_TL1 = "Semi-empirical"; }
	elsif (($Geo_TL eq "MP2") || ($Geo_TL eq "MP3") || ($Geo_TL eq "MP4")){ $Geo_TL1 = "MP"; }
	elsif (($Geo_TL eq "B3PW91") || ($Geo_TL eq "PBE1PBE") || ($Geo_TL eq "BP86") || ($Geo_TL eq "PW91PW91") || ($Geo_TL eq "PBEPBE") || ($Geo_TL eq "B3LYP")){ $Geo_TL1 = "DFT"; }
	#-------------------------
	$Geo_BasisSetDB = $Geo_BasisSet;
	if ($Geo_BasisSet eq "CC-PVDZ")       { $Geo_BasisSetDB = "cc-pVDZ"; }
	elsif ($Geo_BasisSet eq "AUG-CC-PVDZ"){ $Geo_BasisSetDB = "AUG-cc-pVDZ"; }
	elsif ($Geo_BasisSet eq "CC-PVTZ")    { $Geo_BasisSetDB = "cc-pVTZ"; }
	elsif ($Geo_BasisSet eq "AUG-CC-PVTZ"){ $Geo_BasisSetDB = "AUG-cc-pVTZ"; }
	elsif ($Geo_BasisSet eq "CC-PVQZ")    { $Geo_BasisSetDB = "cc-pVQZ"; }
	elsif ($Geo_BasisSet eq "AUG-CC-PVQZ"){ $Geo_BasisSetDB = "AUG-cc-pVQZ"; }
	elsif ($Geo_BasisSet eq "CC-PV5Z")    { $Geo_BasisSetDB = "cc-pV5Z"; }
	elsif ($Geo_BasisSet eq "AUG-CC-PV5Z"){ $Geo_BasisSetDB = "AUG-cc-pV5Z"; }
	#-------------------------
	$Elec_ProgramDB=$Elec_Program;
	if ($Elec_Program eq "JAGUAR"){ $Elec_ProgramDB = "Jaguar"; }
	elsif ($Elec_Program eq "NWCHEM"){ $Elec_ProgramDB = "NWCHem"; }
	#-------------------------
	if ($Elec_TL eq "HF")  { $Elec_TL1 = "HF"; $Elec_TL = ""; }
	elsif ($Elec_TL eq "RHF") { $Elec_TL1 = "RHF"; $Elec_TL = ""; }
	elsif ($Elec_TL eq "UHF") { $Elec_TL1 = "UHF"; $Elec_TL = ""; }
	elsif (($Elec_TL eq "PM3") || ($Elec_TL eq "AM1")){ $Elec_TL1 = "Semi-empirical"; }
	elsif (($Elec_TL eq "MP2") || ($Elec_TL eq "MP3") || ($Elec_TL eq "MP4")){ $Elec_TL1 = "MP"; }
	elsif (($Elec_TL eq "B3PW91") || ($Elec_TL eq "PBE1PBE") || ($Elec_TL eq "BP86") || ($Elec_TL eq "PW91PW91") || ($Elec_TL eq "PBEPBE") || ($Elec_TL eq "B3LYP")){ $Elec_TL1 = "DFT"; }
	#-------------------------
	$Elec_BasisSetDB = $Elec_BasisSet;
	if ($Elec_BasisSet eq "CC-PVDZ")       { $Elec_BasisSetDB = "cc-pVDZ"; }
	elsif ($Elec_BasisSet eq "AUG-CC-PVDZ"){ $Elec_BasisSetDB = "AUG-cc-pVDZ"; }
	elsif ($Elec_BasisSet eq "CC-PVTZ")    { $Elec_BasisSetDB = "cc-pVTZ"; }
	elsif ($Elec_BasisSet eq "AUG-CC-PVTZ"){ $Elec_BasisSetDB = "AUG-cc-pVTZ"; }
	elsif ($Elec_BasisSet eq "CC-PVQZ")    { $Elec_BasisSetDB = "cc-pVQZ"; }
	elsif ($Elec_BasisSet eq "AUG-CC-PVQZ"){ $Elec_BasisSetDB = "AUG-cc-pVQZ"; }
	elsif ($Elec_BasisSet eq "CC-PV5Z")    { $Elec_BasisSetDB = "cc-pV5Z"; }
	elsif ($Elec_BasisSet eq "AUG-CC-PV5Z"){ $Elec_BasisSetDB = "AUG-cc-pV5Z"; }
	#-------------------------
	# if ($Elec_SurfAlgo eq "CONNOLLY SURFACE"){
	# $Elec_SurfAlgo = "Connolly surface";
	# }
	#-------------------------
	#
	# Code to be further developed
	#
}

sub InsertData1{
	my $quote1 = "''";
	$Project_Name=~ s/'/$quote1/g;
	my $slash1 = "\\\\";
	$Project_Name=~ s/\\/$slash1/g;
	print INSERT "INSERT INTO Project VALUES ('$NbP','$Project_Name','$WholeFragment','$REDInterface','$dateUs','','$DateProtect','$NbUser[1]');\n";
	print INSERT "\n";
	if($Published eq "NO"){
		for (my $InsertPub = 0; $InsertPub<=5; $InsertPub++){ $Pubinfo[$InsertPub] = ""; } # to be further developed...
	}
	my $quote2 = "''";
	$Pubinfo[0]=~ s/'/$quote2/g;
	my $slash2 = "\\\\";
	$Pubinfo[0]=~ s/\\/$slash2/g;
	my $quote3 = "''";
	$Pubinfo[1]=~ s/'/$quote3/g;
	my $slash3 = "\\\\";
	$Pubinfo[1]=~ s/\\/$slash3/g;
	print INSERT "INSERT INTO Publication VALUES ('','$Published','$Pubinfo[0]','$Pubinfo[1]','$Pubinfo[2]','$Pubinfo[3]','$Pubinfo[4]','$Pubinfo[5]','$NbP');\n";
	print INSERT "\n";
	for (my $Insert_key=0; $Insert_key<=4; $Insert_key++){
		my $quote4 = "''";
		$Molecule_Keyword[$Insert_key]=~ s/'/$quote4/g;
		my $slash4 = "\\\\";
		$Molecule_Keyword[$Insert_key]=~ s/\\/$slash4/g;
		print INSERT "INSERT INTO Keyword VALUES ('','$Molecule_Keyword[$Insert_key]','$NbP');\n"
	}
	print INSERT "\n";
}

sub InsertData2{
	print INSERT "INSERT INTO Calcul VALUES ('','$Geo_ProgramDB','$Geo_TL1','$Geo_TL','$Geo_MoreInfo','$Geo_BasisSetDB','$Elec_ProgramDB','$Elec_TL1','$Elec_TL','$Elec_MoreInfo','$Elec_BasisSetDB','$Elec_SurfAlgo','RESP','$i_inp','$NbP');\n";
	print INSERT "\n";
	for (my $i_insert_path_ffile = 0; $i_insert_path_ffile<$i_file; $i_insert_path_ffile++){
		if($FF_File[$i_insert_path_ffile][0] eq "YES"){
			my $i_insert_path_ffile_tmp = $i_insert_path_ffile + 1;
			system("cp $FF_File[$i_insert_path_ffile][1] $WholeFragmentDir/script$i_insert_path_ffile_tmp.ff");
			print INSERT "INSERT INTO Scripts VALUES ('','$WholeFragmentDir','$dirserver/$WholeFragmentDir/script$i_insert_path_ffile_tmp.ff','YES','$NbP');\n";
		}
		else{
			my $i_insert_path_ffile_tmp = $i_insert_path_ffile + 1;
			open(FFSCRIPT,">$WholeFragmentDir/script$i_insert_path_ffile_tmp.ff");
			print FFSCRIPT "# R.E.DD.B. project: $WholeFragmentDir\n#\n";
			if ($i_insert_path_ffile == 0) {
				print FFSCRIPT "# A script to convert Tripos mol2 file(s) into LEaP OFF library(ies) (for AMBER)\n#\n\n";
			}
			if ($i_insert_path_ffile == 1) {
				print FFSCRIPT "# A script to convert Tripos mol2 file(s) into RTF or PSF library(ies) (for CHARMM)\n#\n\n";
			}
			if ($i_insert_path_ffile == 2) {
				print FFSCRIPT "# A file to provide new force field parameters compatible with Tripos mol2 file(s)\n#\n\n";
			}
			if ($i_insert_path_ffile == 3) {
				print FFSCRIPT "# A 1st file (choice made by the author) to provide more information about this project\n#\n\n";
			}
			if ($i_insert_path_ffile == 4) {
				print FFSCRIPT "# A 2nd file (choice made by the author) to provide more information about this project\n#\n\n";
			}
			print FFSCRIPT "So far, not yet provided by the author who made the $WholeFragmentDir project submission\n\n";
			print FFSCRIPT "This script might be provided later on by the author (by \"updating\" this project)";
			close(FFSCRIPT);
			print INSERT "INSERT INTO Scripts VALUES ('','$WholeFragmentDir','$dirserver/$WholeFragmentDir/script$i_insert_path_ffile_tmp.ff','NO','$NbP');\n";
		}
	}
	print INSERT "\n";
}

sub InsertData3{
	for (my $i_Insert_path_mol2 = 0;$i_Insert_path_mol2<$i_mol2;$i_Insert_path_mol2++){
		my @tmp = (split('/',$TriposFile_Name[$i_Insert_path_mol2][1]));
		my $a=0;
		$tmp[$a]="";
		while ($tmp[$a] ne ""){ $a++; }
		$initialnamefile_mol2=$tmp[$a-1];
		my $namefile_mol2_tmp = $i_Insert_path_mol2+1;
		$namefile_mol2 = "tripos$namefile_mol2_tmp.mol2";
		system("cp $TriposFile_Name[$i_Insert_path_mol2][1] $WholeFragmentDir/$namefile_mol2");
		my $quote5 = "''";
		$TriposFile_Name[$i_Insert_path_mol2][0]=~ s/'/$quote5/g;
		my $slash5 = "\\\\";
		$TriposFile_Name[$i_Insert_path_mol2][0]=~ s/\\/$slash5/g;
		print INSERT "INSERT INTO Molfile VALUES ('$NbF','$TriposFile_Name[$i_Insert_path_mol2][0]','$namefile_mol2','$WholeFragmentDir','$dirserver/$WholeFragmentDir/$namefile_mol2','$initialnamefile_mol2','Tripos','$NbP');\n";
		if (($ResultTestCont == 0) && ($ResultIfRoot == 0 )){
			if ($ResultVerifPassword == 0){ $NbF++; }
		}
	}
	print INSERT "\n";
	for(my $i_Insert_path_inp = 0;$i_Insert_path_inp<$i_inp;$i_Insert_path_inp++){
		my @tmp = (split('/',$Input_file[$i_Insert_path_inp][0]));
		my $a=0;
		$tmp[$a]="";
		while ($tmp[$a] ne ""){ $a++; }
		$initialnamefile_inp=$tmp[$a-1];
		my $namefile_inp_tmp = $i_Insert_path_inp+1;
		$namefile_inp = "input$namefile_inp_tmp.in";
		system("cp $Input_file[$i_Insert_path_inp][0] $WholeFragmentDir/$namefile_inp");
		print INSERT "INSERT INTO Molfile VALUES ('$NbF','$initialnamefile_inp','$namefile_inp','$WholeFragmentDir','$dirserver/$WholeFragmentDir/$namefile_inp','$initialnamefile_inp','RESP input','$NbP');\n";
		if (($ResultTestCont == 0) && ($ResultIfRoot == 0 )){
			if ($ResultVerifPassword == 0){ $NbF++; }
		}
	}
	print INSERT "\n";
	for (my $Insert_PDBFile_Name = 0;$Insert_PDBFile_Name<$i_pdb;$Insert_PDBFile_Name++){
		my @tmp = (split('/',$molinfo[$Insert_PDBFile_Name][4]));
		my $a=0;
		$tmp[$a]="";
		while ($tmp[$a] ne ""){ $a++; }
		$initialnamefile_pdb=$tmp[$a-1];
		my $namefile_pdb_tmp = $Insert_PDBFile_Name+1;
		$namefile_pdb = "mol$namefile_pdb_tmp.pdb";
		system("cp $molinfo[$Insert_PDBFile_Name][4] $WholeFragmentDir/$namefile_pdb");
		my $quote6 = "''";
		$molinfo[$Insert_PDBFile_Name][0]=~ s/'/$quote6/g;
		my $slash6 = "\\\\";
		$molinfo[$Insert_PDBFile_Name][0]=~ s/\\/$slash6/g;
		print INSERT "INSERT INTO Molfile VALUES ('$NbF','$molinfo[$Insert_PDBFile_Name][0]','$namefile_pdb','$WholeFragmentDir','$dirserver/$WholeFragmentDir/$namefile_pdb','$initialnamefile_pdb','PDB','$NbP');\n";
		if ($molinfo[$Insert_PDBFile_Name][2] eq "RBRA"){
			$softwaremolinfo = "Rigid Body Reorient Algo";
		}else{
			$softwaremolinfo = "QM Reorient Algo $Geo_ProgramDB"
		}
		print INSERT "INSERT INTO Molinfo VALUES ('','$molinfo[$Insert_PDBFile_Name][1]','$softwaremolinfo','$molinfo[$Insert_PDBFile_Name][3]','$NbF');\n";
		if (($ResultTestCont == 0) && ($ResultIfRoot == 0 )){
			if ($ResultVerifPassword == 0){ $NbF++; }
		}
	}
	print INSERT "\n";
	# for (my $Insert2_PDBFile_Name = 0;$Insert2_PDBFile_Name<$i_pdb;$Insert2_PDBFile_Name++){
	# 	if ($molinfo[$Insert2_PDBFile_Name][3] eq "RBRA"){
	# 		$softwaremolinfo = "Rigid Body Reorient Algo";
	# 	}else{
	# 		$softwaremolinfo = "QM Reorient Algo"
	# 	}
	# print INSERT "INSERT INTO Molinfo VALUES ('','$molinfo[$Insert2_PDBFile_Name][1]','$softwaremolinfo','$molinfo[$Insert2_PDBFile_Name][3]','$NbF');\n";
	# }
}

sub InsertData4{
	open (SUMMARY, ">$WholeFragmentDir/summary.txt");
	open (FILECFG, "<$ARGV[0]");
	foreach(<FILECFG>){
		if(/<Abstract>/ .. /<!_Abstract>/){ 
			if (($_ !~ /<Abstract>/) && ($_ !~ /<!_Abstract>/)){ printf SUMMARY ("$_"); }
		}
	}
	close (FILECFG);
	close (SUMMARY);
	# open(SUMMARY,">$WholeFragmentDir/summary.txt");
	# print SUMMARY "$Abstract";
	# close(SUMMARY);
}

sub SubmitREDDB{
	# $SQLFile = "../SQL-dump/REDDB-Official-MySQL-dump.sql";
	$SQLFile = "../SQL-dump/REDDB-Review-MySQL-dump-soumission.sql";
	system ("mysqldump -u $REDDB_Root_Login -p$REDDB_Root_Password MOL2DBR > $SQLFile");

	$NBLine1=$NBLine3=0;

	if ($? == 0){
		$useremail = "$REDDB_Login";
		if (-e "$SQLFile") {
			open(SQLF,"< $SQLFile");
			foreach(<SQLF>){
				if(/^INSERT INTO `Project`/ig)   { $NBLine1++; }
				if(/^INSERT INTO `Users`/ig)     { $NBLine2++; }
				if(/^INSERT INTO `Molfile`/ig)   { $NBLine3++; }
			}
			close(SQLF);
			if ($NBLine1==0) { 
				print "\n\t Empty table - No project available \n";
				$WP=0; $FP=0;
			}
			elsif ($NBLine1==1) {
				open(SQLF,"< $SQLFile");
				foreach(<SQLF>){
					if(/^INSERT INTO `Project`/ig) {
						@WP = split("\'\,\'W\'\,\'");
						@FP = split("\'\,\'F\'\,\'");
						$WP=$#WP+1; $WP--;
						$FP=$#FP+1; $FP--;
					}
				}
				close(SQLF);
				# print "\n\t NBLine1 = $NBLine1; My SQL DB case 11 \n";
			}
			else {
				open(SQLF,"< $SQLFile");
				foreach(<SQLF>){
					if(/^INSERT INTO `Project`/ig) {
						if(/\',\'W\',\'/) { $WP++; }
						if(/\',\'F\',\'/) { $FP++; }
					}
				}
				close(SQLF);
				# print "\n\t NBLine1 = $NBLine1; My SQL DB case 21 \n";
			}
			#########################################################################
			if ($NBLine2==0) {
				print "\n\t Empty table - No user available: Error!\n";
			}
			elsif ($NBLine2==1) {
				open(SQLF,"< $SQLFile");
				foreach(<SQLF>){
					if(/^INSERT INTO `Users`/ig) {
						if(/$useremail/ig) {
							($NbUserTemp1,$NbUserTemp2)=(split("$useremail"))[0,1];
							@NbUser2 = split("','",$NbUserTemp1);
							for (my $i=0; $i<5; $i++) { $#NbUser2--; }
							$N1=$#NbUser2;
							@NbUser1 = split(",'",$NbUser2[$N1]);
							@NbUser = split(/\(/,$NbUser1[0]);
							# $NbUser[1]=~s/\W//gi;
							# print "\n\t 1-> $NbUserTemp1 \n";
							# print "\n\t 2-> $NbUser2[$N1] ";
							# print "\n\t 3-> $NbUser1[0] ";
							# print "\n\t 4-> $NbUser[1] \n";
						}
					}
				}
				close(SQLF);
				# print "\n\t NBLine2 = $NBLine2; My SQL DB case 12 \n";
				open(SQLF,"< $SQLFile");
				foreach(<SQLF>){
					if(/^INSERT INTO `Users`/ig) {
						if(/$useremail/ig) {
							($NbpwdTemp1,$NbpwdTemp2)=(split("$useremail"))[0,1];
							@Nbpwd2 = split("','",$NbpwdTemp1);
							$N2=$#Nbpwd2;
							$Nbpwd=$Nbpwd2[$N2];
							# print "\n\t 1-> $NbpwdTemp1 \n";
							# print "\n\t 2-> $Nbpwd2[$N2] ";
						}
					}
				}
				close(SQLF);
				# print "\n\t NBLine2 = $NBLine2; My SQL DB case 12 \n";
			}
			else {
				open(SQLF,"< $SQLFile");
				foreach(<SQLF>){
					if(/^INSERT INTO `Users`/ig) {
						if(/$useremail/) { 
							@NbUser = split(",'");
							$NbUser[0]=~s/\W|[a-zA-Z]//gi;
							$NbUser[1]=$NbUser[0];
							# print "\n\t 1-> $NbUser[0] \n";
						}
					}
				}
				close(SQLF);
				# print "\n\t NBLine2 = $NBLine2; My SQL DB case 22 \n";
				open(SQLF,"< $SQLFile");
				foreach(<SQLF>){
					if(/^INSERT INTO `Users`/ig) {
						if(/$useremail/) { 
							@Nbpwd2 = split(",'");
							$Nbpwd2[6]=~s/\W//gi;
							$Nbpwd=$Nbpwd2[6];
							# print "\n\t 1-> $Nbpwd \n";
						}
					}
				}
				close(SQLF);
				# print "\n\t NBLine2 = $NBLine2; My SQL DB case 22 \n";
			}
			#########################################################################
			if ($NBLine3==0) {
				print "\n\t Empty table - No mol2-PDB-IN file available\n";
				$TriposF=0; $PDBF=0; $RespIF=0;
			}
			elsif ($NBLine3==1) {
				open(SQLF,"< $SQLFile");
				foreach(<SQLF>){
					if(/^INSERT INTO `Molfile`/ig) {
						@TriposF = split("Tripos");
						@PDBF = split("PDB");
						@RespIF = split("RESP input");
						$TriposF=$#TriposF+1; $TriposF--;
						$PDBF=$#PDBF+1; $PDBF--;
						$RespIF=$#RespIF+1; $RespIF--;
					}
				}
				close(SQLF);
				# print "\n\t NBLine3 = $NBLine3; My SQL DB case 13 \n";
			}
			else {
				open(SQLF,"< $SQLFile");
				foreach(<SQLF>){
					if(/^INSERT INTO `Molfile`/ig) {
						if(/Tripos/) { $TriposF++; }
						if(/PDB/) { $PDBF++; }
						if(/RESP input/) { $RespIF++; }
					}
				}
				close(SQLF);
				# print "\n\t NBLine3 = $NBLine3; My SQL DB case 23 \n";
			}
			$NbP = $WP + $FP;
			# print "\n\t NbP = $NbP;     WP = $WP; FP = $FP \n";
			# if (defined($NbUser[1])) { print "\n\t Nbuser = $NbUser[1] \n"; }
			# if (defined($Nbpwd)) { print "\n\t Nbpwd = $Nbpwd \n"; }
			$NbF = $TriposF + $PDBF + $RespIF;
			# print "\n\t NbF = $NbF;     TriposF = $TriposF; PDBF = $PDBF; RespIF = $RespIF \n";
			$NbP = $NbP +1;
			$NbF = $NbF +1;
			############################################################################
			if (defined($NbUser[1]) && ($Nbpwd eq "$REDDB_Password")){
				$DirPar = (split('/',$Pathfile))[0];
				open(INSERT,">$DirPar-insert.sql");

				if ($WholeFragment eq "W"){ my $WPtmp = $WP+1; $WholeFragmentDir = "$WholeFragment-$WPtmp"; }
				else{ my $FPtmp = $FP+1; $WholeFragmentDir = "$WholeFragment-$FPtmp"; }
				system("mkdir $WholeFragmentDir");

				CalculTime();
				InsertData1();
				DataMisc();
				InsertData2();
				InsertData3();
				InsertData4();

				close(INSERT);

				# To activated or de-activated...
				system("mysql -u $REDDB_Root_Login -p$REDDB_Root_Password MOL2DBR < $DirPar-insert.sql");
				if ($? == 0){
					system("cp -r $WholeFragmentDir ../review");
					system("chmod 777 ../review/$WholeFragmentDir");
					if (-e "./0htaccess") { system("cp 0htaccess ../review/$WholeFragmentDir/.htaccess"); }
				}
				else { print "\n Problem nothing recorded in the review database...\n" ; }
				print "\n==================================================================\n";
				print "Submission in R.E.DD.B. for reviewing...\t[OK]\n\n";
				print "Admin: add the htaccess file and create the index file\n";
				print "\n==================================================================\n";
			}
			else{ print ("\nThe user email is not found in the database or the password is not correct!\n"); }
		}else{ print ("The SQL file is not found!\n"); }
	}
	else{ print ("The MySQL dump did not work\n"); }
}

sub SubmitREDDBlocal{
	$DirPar = (split('/',$Pathfile))[0];
	open(INSERT,">$DirPar-insert.sql");

	$WholeFragmentDir = "$WholeFragment-X"; $NbP = "<nbproject>"; $NbF = "<nbfile>"; $NbUser[1] = "<nbusers>";
	system("mkdir $WholeFragmentDir");

	print INSERT "#\n# This $DirPar-insert.sql file has been generated by the Script2-REDDB.pl program\n#\n";
	print INSERT "# Please, create an archive file for this \"$DirPar-insert.sql\" file and for the \"$WholeFragmentDir\" directory\n";
	print INSERT "# and send this file to the q4md-forcefieldtools team at contact\@q4md-forcefieldtools.org\n#\n";
	print INSERT "# The submission of your data in R.E.DD.B. will be initiated...\n#\n";

	CalculTime();
	InsertData1();
	DataMisc();
	InsertData2();
	InsertData3();
	InsertData4();

	close(INSERT);

	print "\n==================================================================\n";
	print "Preparation of the data for pre-submission in R.E.DD.B...\t[OK]\n\n";
	print "- The \"$DirPar-insert.sql\" file has been generated for your project.\n";
	print "- The \"$WholeFragmentDir\" has been generated for your project.\n\n";
	print "Please, create an archive file for the \"$DirPar-insert.sql\" file and for the \"$WholeFragmentDir\" directory\n";
	print " and send this file to the q4md-forcefieldtools team at contact\@q4md-forcefieldtools.org\n\n";
	print "The submission of your data in R.E.DD.B. will be initiated...\n";
	print "==================================================================\n";
}

#=============== Main =================
$ResultVerifDir = VerifDir();
if ($ResultVerifDir == 0){
	RecupData();
	$ResultIfRoot = IfRoot();
	$ResultTestCont = TestCont();
	if (($ResultTestCont == 0) && ($ResultIfRoot != 0 )){ SubmitREDDBlocal(); print "\n"; }
	else{ 
		if (($ResultTestCont == 0) && ($ResultIfRoot == 0 )){
			$ResultVerifPassword = VerifPassword();
			if ($ResultVerifPassword == 0){ SubmitREDDB(); print "\n"; }
		}
	}
}
